# Программа начальной загрузки с MFBSP SPI флеш-памяти

## Описание
Проект подготовлен для модуля NVCOM-05 Guardian PM.
На вход подаётся два elf-файла: ddr3init для инициализации DDR3 памяти и непосредственно программа,
собранная по адресам DDR3. В python-скрипте происходит чтение входных elf-файлов для определения следующих параметров:
- BASE_MEM - адрес размещения программы в памяти;
- FIRM_ENTRY - точка входа программы, куда spi-boot передаёт управление;
- FIRM_SIZE - размер в байтах, который spi-boot будет выгружать из SPI-Flash;
- FIRM_BASE - адрес программы в SPI-Flash памяти.
*Небходимо для сборки boot-spi1 и boot-spi2*

Порядок загрузки во флеш-память и исполнения следующий:
1. spi-boot1
2. ddr3init
3. spi-boot2
4. firmware (программа, работающая в DDR3)

Для упрощения программирования флеш-памяти python-скрипт подготавливает бинарный образ,
состоящий из всех вышеперечисленных программ `image-boot.img`

## Вызов
Для запуска необходим Python версии 3.5 и выше.
Доступные таргеты для сборки - 
```
chip-name = mc30sf6, mct04, nvcom05, mct06;
board-name = mc30sf6em, mct04em, nvcom05ipkyddr2, mct06em.
```
Строка вызова:

```
$ python3 compile.py --help
usage: compile.py [-h] -c chip (-b board | -i <ddr3init.elf>) -f <u-boot>
                  [-t <mipsel-elf32->]

Create binary bootloader for ELVEES Mips Multicores

optional arguments:
  -h, --help            show this help message and exit
  -c chip, --chip-name chip
                        Name of the chip, the bootloader is building for
  -b board, --board-name board
                        Name of the board, in case of using our memory
                        initialization
  -i <ddr3init.elf>, --ram-init <ddr3init.elf>
                        Path to memory initialization elf file, in case of
                        using external one
  -f <u-boot>, --firmware <u-boot>
                        Path to firmware elf file
  -t <mipsel-elf32->, --triple <mipsel-elf32->
                        Triple to use as cross compile
```

## Примечание
image_boot.img можно прошить во флеш-память с помощью mcprog(http://dwarf.elvees.com:8080/job/BUILD_MCPROG/job/master/) командами:

### NVCom-05 Flash Program
```
# 1. Program SPI Flash (connected to MFBSP)
$ mcprog -b nvcom-05 -f -e1 image-boot.img 0x0
```

### MC30SF6EM Flash Program
```
# Bootloader first stage is in Parallel Flash (connected to CSCON3)
# 1. Program Parallel Flash
$ ./mcprog -e2 -b mc-30sf6em <path-to>/boot-spi1.bin 0xbfc00000

# 2. Program SPI Flash (connected to MFBSP)
$ ./mcprog -e2 -b mc-30sf6em -f <path-to>/image-boot.img 0x0
```

### MCT04EM Flash Program
```
# 1. Program SPI Flash (connected to MFBSP)
$ ./mcprog -e2 -b mct-04 -f <path-to>/image-boot.img 0x0
```

### MCT06EM Flash Program
```
# In case BOOT[1:0] equals b11, then
# 1. Program SPI Flash (connected to MFBSP)
$ ./mcprog -e2 -b mct-06 -f <path-to>/image-boot.img 0x0



# In case BOOT[1:0] equals b01, then bootloader first stage is in the Parallel Flash.
# 1. Program Parallel Flash (connected to CSCON3)
$ ./mcprog -e2 -b mct-06 <path-to>/boot-spi1.bin 0xbfc00000

# 2. Program SPI Flash if isn't done before (connected to MFBSP)
$ ./mcprog -e2 -b mct-06 -f <path-to>/image-boot.img 0x0
```
